<?php

namespace Drupal\facets_range_datepicker_widget\Plugin\facets\widget;

use Drupal\Core\Form\FormStateInterface;
use Drupal\facets\FacetInterface;
use Drupal\facets\Widget\WidgetPluginBase;

/**
 * The datepicker widget.
 *
 * @FacetsWidget(
 *   id = "datepicker",
 *   label = @Translation("Datepicker"),
 *   description = @Translation("A widget that shows a datepicker."),
 * )
 */
class DatepickerWidget extends WidgetPluginBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function build(FacetInterface $facet) {
    $build = parent::build($facet);

    $results = $facet->getResults();
    if (empty($results)) {
      return $build;
    }
    ksort($results);

    $show_numbers = $facet->getWidgetInstance()->getConfiguration()['show_numbers'];
    $urls = [];
    $labels = [];

    foreach ($results as $result) {
      $urls['f_' . $result->getRawValue()] = $result->getUrl()->toString();
      $labels[] = $result->getDisplayValue() . ($show_numbers ? ' (' . $result->getCount() . ')' : '');
    }

    $active = $facet->getActiveItems();
    if (isset($active[0][0])) {
      $default = date('Y-m-d', $active[0][0]);
    }
    else {
      $default = date('Y-m-d', time());
    }
    $build['#items'] = [];
    $build['#items']['min'] = [
      [
        '#type' => 'html_tag',
        '#tag' => 'input',
        '#attributes' => [
          'type' => 'date',
          'class' => ['facet-datepicker'],
          'id' => $facet->id() . '-min',
          'name' => $facet->id() . '-min',
          'value' => $default,
        ],
      ],
    ];

    $url = array_shift($results)->getUrl()->toString();
    $build['#attached']['drupalSettings']['facets']['datepicker'][$facet->id()] = [
      'url' => $url,
    ];

    $build['#attached']['library'][] = 'facets_range_datepicker_widget/datepicker';

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state, FacetInterface $facet) {
    $config = $this->getConfiguration();
    return parent::buildConfigurationForm($form, $form_state, $facet);
  }

  /**
   * {@inheritdoc}
   */
  public function isPropertyRequired($name, $type) {
    if (($name === 'datepicker') && $type === 'processors') {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getQueryType() {
    return 'range';
  }

}
