<?php

namespace Drupal\facets_range_datepicker_widget\Plugin\facets\widget;

use Drupal\facets\FacetInterface;

/**
 * The Datepicker widget.
 *
 * @FacetsWidget(
 *   id = "range_datepicker",
 *   label = @Translation("Range Datepicker"),
 *   description = @Translation("A widget that shows a datepicker slider."),
 * )
 */
class RangeDatepickerWidget extends DatepickerWidget {

  /**
   * {@inheritdoc}
   */
  public function build(FacetInterface $facet) {
    $build = parent::build($facet);

    $results = $facet->getResults();
    if (empty($facet->getResults())) {
      return $build;
    }

    $active = $facet->getActiveItems();
    if (isset($active[0][0])) {
      $default = date('Y-m-d', $active[0][0]);
    }
    else {
      $default = date('Y-m-d', time());
    }

    $build['#items']['max'] = [
      [
        '#type' => 'html_tag',
        '#tag' => 'input',
        '#attributes' => [
          'type' => 'date',
          'class' => ['facet-datepicker'],
          'id' => $facet->id() . '-max',
          'name' => $facet->id() . '-max',
          'value' => $default,
        ],
      ],
    ];

    $build['#items']['submit'] = [
      [
        '#type' => 'html_tag',
        '#tag' => 'button',
          '#value' => $this->t('Submit'),
        '#attributes' => [
          'type' => 'submit',
          'class' => ['facet-datepicker-submit'],
          'id' => $facet->id(),
        ],
      ],
    ];


    $url = array_shift($results)->getUrl()->toString();
    $build['#attached']['drupalSettings']['facets']['datepicker'][$facet->id()] = [
      'url' => $url,
    ];

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getQueryType() {
    return 'range';
  }

}
